==> qtjambi-qt3dcore-5.15.6-sources.jar: io/qt/qt3d/core/QNode.java <==
package io.qt.qt3d.core;


/**
 * <p>The base class of all Qt3D node classes used to build a Qt3D scene</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html">Qt3DCore::QNode</a></p>
 */
public class QNode extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QNode.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#PropertyTrackingMode-enum">Qt3DCore::QNode::PropertyTrackingMode</a></p>
     */
    public enum PropertyTrackingMode implements io.qt.QtShortEnumerator {
        TrackFinalValues((short)0),
        DontTrackValues((short)1),
        TrackAllValues((short)2);

        private PropertyTrackingMode(short value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public short value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static PropertyTrackingMode resolve(short value) {
            switch (value) {
            case 0: return TrackFinalValues;
            case 1: return DontTrackValues;
            case 2: return TrackAllValues;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final short value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#defaultPropertyTrackingMode-prop">Qt3DCore::QNode::defaultPropertyTrackingModeChanged(Qt3DCore::QNode::PropertyTrackingMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="defaultPropertyTrackingMode")
    public final Signal1<io.qt.qt3d.core.QNode.PropertyTrackingMode> defaultPropertyTrackingModeChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#enabled-prop">Qt3DCore::QNode::enabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="enabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> enabledChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#nodeDestroyed">Qt3DCore::QNode::nodeDestroyed()</a></p>
     */
    public final Signal0 nodeDestroyed = new Signal0();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#parent-prop">Qt3DCore::QNode::parentChanged(QObject*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="parent")
    public final Signal1<io.qt.core.QObject> parentChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QNode(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QNode() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#QNode">Qt3DCore::QNode::QNode(Qt3DCore::QNode*)</a></p>
     */
    public QNode(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QNode instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#blockNotifications">Qt3DCore::QNode::blockNotifications(bool)</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean blockNotifications(boolean block){
        return blockNotifications_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), block);
    }
    
    @io.qt.QtUninvokable
    private native boolean blockNotifications_native_bool(long __this__nativeId, boolean block);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#childNodes">Qt3DCore::QNode::childNodes()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.core.QNode> childNodes(){
        return childNodes_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.core.QNode> childNodes_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#clearPropertyTracking">Qt3DCore::QNode::clearPropertyTracking(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void clearPropertyTracking(java.lang.String propertyName){
        clearPropertyTracking_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), propertyName);
    }
    
    @io.qt.QtUninvokable
    private native void clearPropertyTracking_native_cref_QString(long __this__nativeId, java.lang.String propertyName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#clearPropertyTrackings">Qt3DCore::QNode::clearPropertyTrackings()</a></p>
     */
    @io.qt.QtUninvokable
    public final void clearPropertyTrackings(){
        clearPropertyTrackings_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearPropertyTrackings_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#defaultPropertyTrackingMode">Qt3DCore::QNode::defaultPropertyTrackingMode()const</a></p>
     */
    @io.qt.QtPropertyReader(name="defaultPropertyTrackingMode")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNode.PropertyTrackingMode defaultPropertyTrackingMode(){
        return io.qt.qt3d.core.QNode.PropertyTrackingMode.resolve(defaultPropertyTrackingMode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native short defaultPropertyTrackingMode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#id">Qt3DCore::QNode::id()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNodeId id(){
        return id_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNodeId id_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#enabled-prop">Qt3DCore::QNode::isEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="enabled")
    @io.qt.QtUninvokable
    public final boolean isEnabled(){
        return isEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#notificationsBlocked">Qt3DCore::QNode::notificationsBlocked()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean notificationsBlocked(){
        return notificationsBlocked_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean notificationsBlocked_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#notifyObservers">Qt3DCore::QNode::notifyObservers(Qt3DCore::QSceneChangePtr)</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final void notifyObservers(io.qt.qt3d.core.QSceneChange change){
        notifyObservers_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), change);
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native void notifyObservers_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.core.QSceneChange change);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#parent-prop">Qt3DCore::QNode::parentNode()const</a></p>
     */
    @io.qt.QtPropertyReader(name="parent")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNode parentNode(){
        return parentNode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNode parentNode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#propertyTracking">Qt3DCore::QNode::propertyTracking(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNode.PropertyTrackingMode propertyTracking(java.lang.String propertyName){
        return io.qt.qt3d.core.QNode.PropertyTrackingMode.resolve(propertyTracking_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), propertyName));
    }
    
    @io.qt.QtUninvokable
    private native short propertyTracking_native_cref_QString_constfct(long __this__nativeId, java.lang.String propertyName);
    
    /**
     * <p>Overloaded function for {@link #sendCommand(java.lang.String, java.lang.Object, int)}
     *  with <code>replyTo = 0</code>.</p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    public final int sendCommand(java.lang.String name, java.lang.Object data) {
        return sendCommand(name, data, (int)0);
    }
    
    /**
     * <p>Overloaded function for {@link #sendCommand(java.lang.String, java.lang.Object, int)}</p>
     * <p>with: </p><ul>
     * <li><code>data = null</code></li>
     * <li><code>replyTo = 0</code></li>
     * </ul>
     */
    @Deprecated
    @io.qt.QtUninvokable
    public final int sendCommand(java.lang.String name) {
        return sendCommand(name, (java.lang.Object)null, (int)0);
    }
    
    /**
     * <p>Sends a command message to the backend node</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#sendCommand">Qt3DCore::QNode::sendCommand(QString,QVariant,Qt3DCore::QNodeCommand::CommandId)</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    public final int sendCommand(java.lang.String name, java.lang.Object data, int replyTo){
        return sendCommand_native_cref_QString_cref_QVariant_unsigned_int(QtJambi_LibraryUtilities.internal.nativeId(this), name, data, replyTo);
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native int sendCommand_native_cref_QString_cref_QVariant_unsigned_int(long __this__nativeId, java.lang.String name, java.lang.Object data, int replyTo);
    
    /**
     * <p>Send a command back to the backend node</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#sendReply">Qt3DCore::QNode::sendReply(Qt3DCore::QNodeCommandPtr)</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    public final void sendReply(io.qt.qt3d.core.QNodeCommand command){
        sendReply_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), command);
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native void sendReply_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.core.QNodeCommand command);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#defaultPropertyTrackingMode-prop">Qt3DCore::QNode::setDefaultPropertyTrackingMode(Qt3DCore::QNode::PropertyTrackingMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="defaultPropertyTrackingMode")
    public final void setDefaultPropertyTrackingMode(io.qt.qt3d.core.QNode.PropertyTrackingMode mode){
        setDefaultPropertyTrackingMode_native_Qt3DCore_QNode_PropertyTrackingMode(QtJambi_LibraryUtilities.internal.nativeId(this), mode.value());
    }
    
    private native void setDefaultPropertyTrackingMode_native_Qt3DCore_QNode_PropertyTrackingMode(long __this__nativeId, short mode);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#enabled-prop">Qt3DCore::QNode::setEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="enabled")
    public final void setEnabled(boolean isEnabled){
        setEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), isEnabled);
    }
    
    private native void setEnabled_native_bool(long __this__nativeId, boolean isEnabled);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#parent-prop">Qt3DCore::QNode::setParent(Qt3DCore::QNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="parent")
    public final void setParent(io.qt.qt3d.core.QNode parent){
        setParent_native_Qt3DCore_QNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    private native void setParent_native_Qt3DCore_QNode_ptr(long __this__nativeId, long parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#setPropertyTracking">Qt3DCore::QNode::setPropertyTracking(QString,Qt3DCore::QNode::PropertyTrackingMode)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setPropertyTracking(java.lang.String propertyName, io.qt.qt3d.core.QNode.PropertyTrackingMode trackMode){
        setPropertyTracking_native_cref_QString_Qt3DCore_QNode_PropertyTrackingMode(QtJambi_LibraryUtilities.internal.nativeId(this), propertyName, trackMode.value());
    }
    
    @io.qt.QtUninvokable
    private native void setPropertyTracking_native_cref_QString_Qt3DCore_QNode_PropertyTrackingMode(long __this__nativeId, java.lang.String propertyName, short trackMode);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#sceneChangeEvent">Qt3DCore::QNode::sceneChangeEvent(Qt3DCore::QSceneChangePtr)</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected void sceneChangeEvent(io.qt.qt3d.core.QSceneChange change){
        sceneChangeEvent_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), change);
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native void sceneChangeEvent_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.core.QSceneChange change);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNode(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QNode(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QNode instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QNode.java <==
package io.qt.qt3d.core;


/**
 * <p>The base class of all Qt3D node classes used to build a Qt3D scene</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html">Qt3DCore::QNode</a></p>
 */
public class QNode extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QNode.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#PropertyTrackingMode-enum">Qt3DCore::QNode::PropertyTrackingMode</a></p>
     */
    public enum PropertyTrackingMode implements io.qt.QtShortEnumerator {
        TrackFinalValues((short)0),
        DontTrackValues((short)1),
        TrackAllValues((short)2);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private PropertyTrackingMode(short value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public short value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static PropertyTrackingMode resolve(short value) {
            switch (value) {
            case 0: return TrackFinalValues;
            case 1: return DontTrackValues;
            case 2: return TrackAllValues;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final short value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#defaultPropertyTrackingMode-prop">Qt3DCore::QNode::defaultPropertyTrackingModeChanged(Qt3DCore::QNode::PropertyTrackingMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="defaultPropertyTrackingMode")
    public final Signal1<io.qt.qt3d.core.QNode.PropertyTrackingMode> defaultPropertyTrackingModeChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#enabled-prop">Qt3DCore::QNode::enabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="enabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> enabledChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#nodeDestroyed">Qt3DCore::QNode::nodeDestroyed()</a></p>
     */
    public final Signal0 nodeDestroyed = new Signal0();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#parent-prop">Qt3DCore::QNode::parentChanged(QObject*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="parent")
    public final Signal1<io.qt.core.QObject> parentChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QNode(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QNode() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#QNode">Qt3DCore::QNode::QNode(Qt3DCore::QNode*)</a></p>
     */
    public QNode(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QNode instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#blockNotifications">Qt3DCore::QNode::blockNotifications(bool)</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean blockNotifications(boolean block){
        return blockNotifications_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), block);
    }
    
    @io.qt.QtUninvokable
    private native boolean blockNotifications_native_bool(long __this__nativeId, boolean block);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#childNodes">Qt3DCore::QNode::childNodes()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.core.QNode> childNodes(){
        return childNodes_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.core.QNode> childNodes_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#clearPropertyTracking">Qt3DCore::QNode::clearPropertyTracking(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void clearPropertyTracking(java.lang.String propertyName){
        clearPropertyTracking_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), propertyName);
    }
    
    @io.qt.QtUninvokable
    private native void clearPropertyTracking_native_cref_QString(long __this__nativeId, java.lang.String propertyName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#clearPropertyTrackings">Qt3DCore::QNode::clearPropertyTrackings()</a></p>
     */
    @io.qt.QtUninvokable
    public final void clearPropertyTrackings(){
        clearPropertyTrackings_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearPropertyTrackings_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#defaultPropertyTrackingMode">Qt3DCore::QNode::defaultPropertyTrackingMode()const</a></p>
     */
    @io.qt.QtPropertyReader(name="defaultPropertyTrackingMode")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNode.PropertyTrackingMode defaultPropertyTrackingMode(){
        return io.qt.qt3d.core.QNode.PropertyTrackingMode.resolve(defaultPropertyTrackingMode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native short defaultPropertyTrackingMode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#id">Qt3DCore::QNode::id()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNodeId id(){
        return id_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNodeId id_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#enabled-prop">Qt3DCore::QNode::isEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="enabled")
    @io.qt.QtUninvokable
    public final boolean isEnabled(){
        return isEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#notificationsBlocked">Qt3DCore::QNode::notificationsBlocked()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean notificationsBlocked(){
        return notificationsBlocked_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean notificationsBlocked_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#notifyObservers">Qt3DCore::QNode::notifyObservers(Qt3DCore::QSceneChangePtr)</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final void notifyObservers(io.qt.qt3d.core.QSceneChange change){
        notifyObservers_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), change);
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native void notifyObservers_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.core.QSceneChange change);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#parent-prop">Qt3DCore::QNode::parentNode()const</a></p>
     */
    @io.qt.QtPropertyReader(name="parent")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNode parentNode(){
        return parentNode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNode parentNode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#propertyTracking">Qt3DCore::QNode::propertyTracking(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNode.PropertyTrackingMode propertyTracking(java.lang.String propertyName){
        return io.qt.qt3d.core.QNode.PropertyTrackingMode.resolve(propertyTracking_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), propertyName));
    }
    
    @io.qt.QtUninvokable
    private native short propertyTracking_native_cref_QString_constfct(long __this__nativeId, java.lang.String propertyName);
    
    /**
     * <p>Overloaded function for {@link #sendCommand(java.lang.String, java.lang.Object, int)}
     *  with <code>replyTo = 0</code>.</p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    public final int sendCommand(java.lang.String name, java.lang.Object data) {
        return sendCommand(name, data, (int)0);
    }
    
    /**
     * <p>Overloaded function for {@link #sendCommand(java.lang.String, java.lang.Object, int)}</p>
     * <p>with: </p><ul>
     * <li><code>data = null</code></li>
     * <li><code>replyTo = 0</code></li>
     * </ul>
     */
    @Deprecated
    @io.qt.QtUninvokable
    public final int sendCommand(java.lang.String name) {
        return sendCommand(name, (java.lang.Object)null, (int)0);
    }
    
    /**
     * <p>Sends a command message to the backend node</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#sendCommand">Qt3DCore::QNode::sendCommand(QString,QVariant,Qt3DCore::QNodeCommand::CommandId)</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    public final int sendCommand(java.lang.String name, java.lang.Object data, int replyTo){
        return sendCommand_native_cref_QString_cref_QVariant_unsigned_int(QtJambi_LibraryUtilities.internal.nativeId(this), name, data, replyTo);
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native int sendCommand_native_cref_QString_cref_QVariant_unsigned_int(long __this__nativeId, java.lang.String name, java.lang.Object data, int replyTo);
    
    /**
     * <p>Send a command back to the backend node</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#sendReply">Qt3DCore::QNode::sendReply(Qt3DCore::QNodeCommandPtr)</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    public final void sendReply(io.qt.qt3d.core.QNodeCommand command){
        sendReply_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), command);
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native void sendReply_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.core.QNodeCommand command);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#defaultPropertyTrackingMode-prop">Qt3DCore::QNode::setDefaultPropertyTrackingMode(Qt3DCore::QNode::PropertyTrackingMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="defaultPropertyTrackingMode")
    public final void setDefaultPropertyTrackingMode(io.qt.qt3d.core.QNode.PropertyTrackingMode mode){
        setDefaultPropertyTrackingMode_native_Qt3DCore_QNode_PropertyTrackingMode(QtJambi_LibraryUtilities.internal.nativeId(this), mode.value());
    }
    
    private native void setDefaultPropertyTrackingMode_native_Qt3DCore_QNode_PropertyTrackingMode(long __this__nativeId, short mode);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#enabled-prop">Qt3DCore::QNode::setEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="enabled")
    public final void setEnabled(boolean isEnabled){
        setEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), isEnabled);
    }
    
    private native void setEnabled_native_bool(long __this__nativeId, boolean isEnabled);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#parent-prop">Qt3DCore::QNode::setParent(Qt3DCore::QNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="parent")
    public final void setParent(io.qt.qt3d.core.QNode parent){
        setParent_native_Qt3DCore_QNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    private native void setParent_native_Qt3DCore_QNode_ptr(long __this__nativeId, long parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode.html#setPropertyTracking">Qt3DCore::QNode::setPropertyTracking(QString,Qt3DCore::QNode::PropertyTrackingMode)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setPropertyTracking(java.lang.String propertyName, io.qt.qt3d.core.QNode.PropertyTrackingMode trackMode){
        setPropertyTracking_native_cref_QString_Qt3DCore_QNode_PropertyTrackingMode(QtJambi_LibraryUtilities.internal.nativeId(this), propertyName, trackMode.value());
    }
    
    @io.qt.QtUninvokable
    private native void setPropertyTracking_native_cref_QString_Qt3DCore_QNode_PropertyTrackingMode(long __this__nativeId, java.lang.String propertyName, short trackMode);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#sceneChangeEvent">Qt3DCore::QNode::sceneChangeEvent(Qt3DCore::QSceneChangePtr)</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected void sceneChangeEvent(io.qt.qt3d.core.QSceneChange change){
        sceneChangeEvent_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), change);
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native void sceneChangeEvent_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.core.QSceneChange change);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNode(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QNode(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QNode instance, QDeclarativeConstructor constructor);
    
}
